==> phpFileManager-1.7.8.zip: README.md <==
# PHP Filesystem Management Tool
https://sourceforge.net/projects/phpfm/

phpFileManager is a complete filesystem management tool on a single file.

This is a tool meant for rapid file access, and also to verify the server php configuration and security.
The script can be renamed and deployed on an unique known url, and offers password protection.

Online Demo: https://phpfm-demo.000webhostapp.com
Feel free to mess around! This is a public demo installation, and will reset itself every 30 min.

## Features:
- directory tree, with ajax loading
- copy/move/delete/create/rename/edit/view/chmod files and folders
- tar/zip/bzip/gzip with native support
- code editor with syntax highlight, using Ace and Monokai theme
- shell terminal emulator
- portscan using PHP sockets
- server info
- multiple uploads
- password protection
- works on linux/mac/windows
- php4/php5/php6/php7 compatible
- translations included for english/portuguese/spanish/catalan/chinese/dutch/french/german/italian/korean/russian/polish/turkish/ukrainian

## License:
phpFileManager is free software; you can redistribute it and/or modify it
under the terms any of the following licenses at your choice:
- GNU General Public License Version 2 or later (the "GPL");
- GNU Lesser General Public License Version 2.1 or later (the "LGPL");
- Mozilla Public License Version 1.1 or later (the "MPL").

## Is it secure?
Short answer. YES! phpFileManager is secure, but you must set a password on it.
The script can be renamed and deployed on an unique known url, that helps you keep it hidden.
But you have to set a password! Obviously!
If you do not, this script will allow any person to access it, that is the default setting.
And that is why i provide this script, with the following disclaimer.

## Disclaimer:
BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.
EXCEPT WHEN OTHERWISE STATED IN WRITING, THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.

==> phpFileManager-1.7.9.zip: README.md <==
# PHP Filesystem Management Tool

https://sourceforge.net/projects/phpfm/

phpFileManager is a complete filesystem management tool on a single file.

This is a tool meant for rapid file access, and also to verify the server php configuration and security.
The script can be renamed and deployed on an unique known url, and offers password protection.

Online Demo: https://phpfm-demo.000webhostapp.com
Feel free to mess around! This is a public demo installation, and will reset itself every 30 min.

![phpFileManager - Demo](https://www.dulldusk.com/assets/files/phpfm/ss1.7.2.png)

## Features:
- directory tree, with ajax loading
- copy/move/delete/create/rename/edit/view/chmod files and folders
- tar/zip/bzip/gzip support
- code editor with syntax highlight, using Ace and Monokai theme
- shell terminal emulator
- portscan using PHP sockets
- server info
- multiple uploads
- password protection
- works on linux/mac/windows
- works on all php versions
- translations included for:
    . catalan
    . chinese
    . dutch
    . english
    . french
    . german
    . italian
    . korean
    . persian/dari
    . portuguese
    . polish
    . serbian
    . spanish
    . russian
    . turkish
    . ukrainian

## License:
phpFileManager is free software; you can redistribute it and/or modify it
under the terms any of the following licenses at your choice:
- GNU General Public License Version 2 or later (the "GPL");
- GNU Lesser General Public License Version 2.1 or later (the "LGPL");
- Mozilla Public License Version 1.1 or later (the "MPL").

## Is it secure?
Short answer. YES! phpFileManager is secure, but you must set a password on it.
The script can be renamed and deployed on an unique known url, that helps you keep it hidden.
But you have to set a password! Obviously!
If you do not, this script will allow any person to access it, that is the default setting.
And that is why i provide this script, with the following disclaimer.

## Disclaimer:
BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.
EXCEPT WHEN OTHERWISE STATED IN WRITING, THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
